import logging

log = logging.getLogger(__name__)


class TaskContext(object):
    def __init__(self, stage_id=0, partition_id=0):
        log.info('Running stage {0} for partition {1}'
                 ''.format(stage_id, partition_id))

        self.stage_id = stage_id
        self.partition_id = partition_id
        self.attempt_number = 0
        self.is_completed = False
        self.is_running_locally = True
        self.task_completion_listeners = []

    def _create_child(self):
        return TaskContext(stage_id=self.stage_id+1,
                           partition_id=self.partition_id)

    def attemptNumber(self):
        return self.attempt_number

    def partitionId(self):
        return self.partition_id

    def stageId(self):
        return self.stage_id



"""pysparkling module."""

__version__ = '0.2.13'

from .exceptions import (FileAlreadyExistsException,
                         ConnectionException)

from .context import Context
from .rdd import RDD
from .broadcast import Broadcast

from . import fileio



import logging

log = logging.getLogger(__name__)


class Codec(object):
    def __init__(self):
        pass

    def compress(self, stream):
        return stream

    def decompress(self, stream):
        return stream



from __future__ import absolute_import

import logging

from .codec import Codec
from .gz import Gz
from .bz2 import Bz2

log = logging.getLogger(__name__)

FILE_ENDINGS = [
    (('gz'), Gz),
    (('bz2'), Bz2),
]


def get_codec(path):
    """Find the codec implementation for this path."""
    if '.' not in path or path.rfind('/') > path.rfind('.'):
        return Codec
    ending = path[path.rfind('.')+1:]

    for endings, codec_class in FILE_ENDINGS:
        if ending in endings:
            log.info('Using {0} codec: {1}'.format(ending, path))
            return codec_class

    return Codec
